@@ -1,9 +1,10 @@
 import time
 import logging
-import consts
+import etools.consts
 
 
-logger = logging.getLogger(consts.LOGGER_NAME)
+logger = logging.getLogger(etools.consts.LOGGER_NAME)
+print(etools.consts.LOGGER_NAME)
 
 
 def clear_none_in_dict(d, recursive=True):
